Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2677)

Unified Diff: chrome/browser/chromeos/drive/job_scheduler.h

Issue 22909041: Refactor GetAboutRequest and GetApplistRequest. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/chromeos/drive/job_scheduler.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/chromeos/drive/job_scheduler.h
diff --git a/chrome/browser/chromeos/drive/job_scheduler.h b/chrome/browser/chromeos/drive/job_scheduler.h
index 9d25786335976b9a70bc50c287b38003395730ae..5b3f0b9fb5aae6012aeefc8523ea06d0b0ee36a1 100644
--- a/chrome/browser/chromeos/drive/job_scheduler.h
+++ b/chrome/browser/chromeos/drive/job_scheduler.h
@@ -65,11 +65,11 @@ class JobScheduler
// Adds a GetAppList operation to the queue.
// |callback| must not be null.
- void GetAppList(const google_apis::GetAppListCallback& callback);
+ void GetAppList(const google_apis::AppListCallback& callback);
// Adds a GetAboutResource operation to the queue.
// |callback| must not be null.
- void GetAboutResource(const google_apis::GetAboutResourceCallback& callback);
+ void GetAboutResource(const google_apis::AboutResourceCallback& callback);
// Adds a GetAllResourceList operation to the queue.
// |callback| must not be null.
@@ -271,10 +271,10 @@ class JobScheduler
google_apis::GDataErrorCode error,
scoped_ptr<google_apis::ResourceEntry> entry);
// Callback for job finishing with a GetAboutResourceCallback.
void OnGetAboutResourceJobDone(
JobID job_id,
- const google_apis::GetAboutResourceCallback& callback,
+ const google_apis::AboutResourceCallback& callback,
google_apis::GDataErrorCode error,
scoped_ptr<google_apis::AboutResource> about_resource);
@@ -285,10 +285,10 @@ class JobScheduler
google_apis::GDataErrorCode error,
const GURL& share_url);
// Callback for job finishing with a GetAppListCallback.
void OnGetAppListJobDone(
JobID job_id,
- const google_apis::GetAppListCallback& callback,
+ const google_apis::AppListCallback& callback,
google_apis::GDataErrorCode error,
scoped_ptr<google_apis::AppList> app_list);
« no previous file with comments | « no previous file | chrome/browser/chromeos/drive/job_scheduler.cc » ('j') | no next file with comments »
@@ -271,10 +271,10 @@ class JobScheduler
google_apis::GDataErrorCode error,
scoped_ptr<google_apis::ResourceEntry> entry);
- // Callback for job finishing with a GetAboutResourceCallback.
+ // Callback for job finishing with a AboutResourceCallback.
void OnGetAboutResourceJobDone(
JobID job_id,
@@ -285,10 +285,10 @@ class JobScheduler
google_apis::GDataErrorCode error,
const GURL& share_url);
- // Callback for job finishing with a GetAppListCallback.
+ // Callback for job finishing with a AppListCallback.
void OnGetAppListJobDone(
JobID job_id,

Powered by Google App Engine
This is Rietveld 408576698